@@ -6,43 +6,10 @@
 
 G_BEGIN_DECLS
 
-typedef void (*UpdateFunction) (gpointer);
-
 #define		sure_string(s)		((const char *)((s)!=NULL?(s):""))
 
-void            panel_util_launch_from_key_file (GKeyFile                *keyfile,
-						 GList                   *file_list,
-						 GdkScreen               *screen,
-						 GError                 **error);
-void            panel_launch_desktop_file  (const char                   *desktop_file,
-					    const char                   *fallback_exec,
-					    GdkScreen                    *screen,
-					    GError                      **error);
-
 char *          panel_util_make_exec_uri_for_desktop (const char *exec);
 
-void		panel_show_help		(GdkScreen  *screen,
-					 const char *path,
-					 const char *linkid);
-
-GList *panel_g_list_insert_before (GList        *list,
-				   GList        *sibling,
-				   GList        *link);
-GList *panel_g_list_insert_after  (GList        *list,
-				   GList        *sibling,
-				   GList        *link);
-GList *panel_g_list_swap_next     (GList        *list,
-				   GList        *dl);
-GList *panel_g_list_swap_prev     (GList        *list,
-				   GList        *dl);
-GList *panel_g_list_resort_item   (GList        *list,
-				   gpointer      data,
-				   GCompareFunc  func);
-
-GSList *panel_g_slist_make_unique (GSList       *list,
-				   GCompareFunc  compare,
-				   gboolean      free_data);
-
 int		panel_find_applet_index	(GtkWidget *widget);
 
 void		panel_push_window_busy	(GtkWidget *window);
@@ -69,6 +36,11 @@ GdkPixbuf *     panel_load_icon         (GtkIconTheme  *icon_theme,
 					 int            desired_height,
 					 char         **error_msg);
 
+GFile      *panel_launcher_get_gfile           (const char *location);
+char       *panel_launcher_get_uri             (const char *location);
+char       *panel_launcher_get_filename        (const char *location);
+gboolean    panel_launcher_is_in_personal_path (const char *location);
+
 char *panel_make_full_path   (const char *dir,
 			      const char *filename);
 char *panel_make_unique_desktop_path_from_name (const char *dir,
@@ -90,9 +62,6 @@ char *panel_util_get_icon_for_uri (const char *text_uri);
 void panel_util_set_tooltip_text (GtkWidget  *widget,
 				  const char *text);
 
-char *panel_util_get_icon_name_from_g_icon (GIcon *gicon);
-GdkPixbuf *panel_util_get_pixbuf_from_g_loadable_icon (GIcon *gicon,
-						       int    size);
 GFile *panel_util_get_file_optional_homedir (const char *location);
 
 G_END_DECLS
